.. horizont documentation master file, created by
   sphinx-quickstart on Fri Nov  1 19:18:47 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

horizont: Dynamic topic models
==============================

horizont implements a number of topic models. Conventions from scikit-learn_ are
followed.

The project is focused on dynamic topic models.

The following models are implemented using Gibbs sampling:

- Latent Dirichlet allocation (Blei et al., 2003; Pritchard et al., 2000)
- (Coming soon) Logistic normal topic model
- (Coming soon) Dynamic topic model (Blei and Lafferty, 2006)


.. toctree::
    :maxdepth: 1

    getting_started
    api
    whats_new


.. _Python: http://www.python.org/
.. _scikit-learn: http://scikit-learn.org
.. _MALLET: http://mallet.cs.umass.edu/
.. _numpy: http://www.numpy.org/
.. _scipy:  http://docs.scipy.org/doc/
